@@ -339,6 +339,7 @@ def make_dict_of_obs(conn_filememory,model_lons,model_lats):
         radarAltitude  = header_entry['ANTENNA_ALTITUDE']
         radar_lon = header_entry['LON']
         radar_lat = header_entry['LAT']
+        
         for data_entry in data_entries:
             this_range   = data_entry['RANGE']
             this_id_datas = data_entry['ID_DATA']
@@ -410,7 +411,6 @@ def get_couple_thinning( dict_obs,
     id_save1 = np.array(())
     id_save2 = np.array(())
     distance = np.array(())
-
     # check model tiles sharing multiple radar observations
     for unique_indices in list_unique_indices:
         # again please use nonzero
@@ -433,7 +433,6 @@ def get_couple_thinning( dict_obs,
                             distance_test = np.append(distance_test, dista)
                             couple_obs1 = np.append( couple_obs1, dict_obs['id_data'][ind1])   
                             couple_obs2 = np.append( couple_obs2, dict_obs['id_data'][ind2]) 
-                            # why a capital letter here?
                             height_test1 = np.append( height_test1, dict_obs['beamHeight'][ind1]) 
                             height_test2 = np.append( height_test2, dict_obs['beamHeight'][ind2]) 
          
@@ -504,9 +503,7 @@ def get_all_thinning(dict_obs,
     """
 
     # get vertical interval to make horizontal thinning
-    Height_interval = list(np.arange(0, int(1.3*max(dict_obs['beamHeight'])), delta_height_vertical_m))
-  
-    # thinning
+    Height_interval = list(np.arange(0, max(dict_obs['beamHeight'])+delta_height_vertical_m, delta_height_vertical_m))
     for h in range(0,len(Height_interval)-1):
         min_height = Height_interval[h]
         max_height = Height_interval[h+1]
@@ -586,7 +583,7 @@ def thinning(pathfileout,
     """ 
   
     #Prepare file in memory
-    filememory=f'file:{os.path.basename(filein)}_{startdate}_{enddate}?mode=memory&cache=shared'
+    filememory=f'file:{startdate}_{enddate}?mode=memory&cache=shared'
     print(filememory)
   
     #print(f'Averaging volume scan for radar {stn} at time {hhmiss_pad} into {os.path.basename(filememory)}')
@@ -644,18 +641,29 @@ def thinning(pathfileout,
                                                           list_id_data_save_thinning, 
                                                           list_id_data_remove_thinning,
                                                           kdtree)
+    for obs_remove_thinning in list_id_data_remove_thinning:
+        if not (np.where( list_id_data_save_thinning == obs_remove_thinning) and 
+                np.where( list_id_data_save_couples == obs_remove_thinning)):  
+            raise ValueError('id_data_remove_thinning in two list')
+        # flag obs not assimilable
+        # flag obs not assimilable
+        order_sql = """UPDATE data set flag=replace(flag,0,2048) where ID_DATA = ?;"""
+        conn_filememory.execute(order_sql,(int(obs_remove_thinning),)) 
   
+
     # test for thinning 
+  #  print ( "---->",dict_obs['id_data'])
     if (list_id_data_save_couples.size+list_id_data_remove_thinning.size+list_id_data_save_thinning.size) != dict_obs['id_data'].size:
-        print (list_id_data_save_couples.size+list_id_data_remove_thinning.size+list_id_data_save_thinning.size)
-        print (dict_obs['id_data'].size)
+       # print (list_id_data_save_couples.size+list_id_data_remove_thinning.size+list_id_data_save_thinning.size)
+       # print (dict_obs['id_data'].size)
+        print (list_id_data_save_couples.size,list_id_data_remove_thinning.size,list_id_data_save_thinning.size, dict_obs['id_data'].size)
         raise ValueError('id_data save in at least two list')
 
     conn_filememory.commit()
-  
+
     # combine in one file to Midas
     try:
-        radvelso.qcavg.combine(pathfileout, filememory)
+        combine(pathfileout, filememory)
     except sqlite3.Error as error:
         print("Error while creating a single sqlite file:  {os.path.basename(filememory)}", error)
     # close connection 
@@ -694,6 +702,48 @@ def find_sample_entry(src_dir, file_type, variable=None, prefix=None):
 
     return out_dict
 
+
+def combine(pathfileout, filememory):
+ 
+    """ Creating a single sqlite file from multiple sqlite files
+   
+    args:
+    ----------------
+    pathfileout   : output averaging  sqlite file 
+    filememory    : name of the sqlite file in memory to copy
+    
+    output:
+    ----------------
+    Nothing
+    A sqlite file is made with all averaged volume scans
+
+    """
+  
+    # write in output averaging  sqlite file
+    conn_pathfileout = sqlite3.connect(pathfileout, uri=True, isolation_level=None, timeout=999)
+    # off the journal
+    conn_pathfileout.execute("""PRAGMA journal_mode=OFF;""")
+    # SQLite continues without syncing as soon as it has handed data off to the operating system
+    conn_pathfileout.execute("""PRAGMA synchronous=OFF;""")
+    # Wait to read and write until the next process finishes
+    # attach the sqlite file in memory for one PPI
+    conn_pathfileout.execute("ATTACH DATABASE ? AS this_avg_db;", (filememory,))
+    order_sql = """ INSERT into header
+                      SELECT
+                       *
+                      FROM  this_avg_db.header;"""
+    conn_pathfileout.execute(order_sql) 
+    order_sql = """ INSERT into data
+                      SELECT
+                        *
+                      FROM  this_avg_db.data;"""
+    conn_pathfileout.execute(order_sql)
+  
+    conn_pathfileout.commit()
+    conn_pathfileout.execute(""" DETACH DATABASE this_avg_db """)
+
+
+
 def compute_thinning(center_time,
                      window_width,
                      infile_list, 
@@ -749,7 +799,7 @@ def compute_thinning(center_time,
         schema = f.read()
     con_infile_combine.executescript(schema)
     for infile in infile_list:
-        radvelso.qcavg.combine(infile_combine, infile)
+        combine(infile_combine, infile)
    # create info and resume_tables in fileout
     create_info_midas_tables(infile, con_infile_combine)  
     con_infile_combine.close()
@@ -784,7 +834,7 @@ def compute_thinning(center_time,
     if len(vol_scan_list) == 0:
         raise RuntimeError("""List of volume scan to process is empty. 
                           Check that files are available and search criteria are correct.""")
-    tc_0 = time.time()
+    tc_0 = time.time() 
     if timing :
         print ("Compute only one PPI ")
         thinning(pathfileout,
